MCD gerund
Ligne de commande ( commande, produit, quantité )

- Le champ commande fait partie de la clé primaire de la table. Il a migré à partir de l'entité Commande pour renforcer l'identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ produit fait partie de la clé primaire de la table. Il a migré à partir de l'entité Produit pour renforcer l'identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ quantité était déjà un simple attribut de l'entité Ligne de commande.

NB. Les tables Commande et Produit ont été supprimées car elles étaient réduites à la clé primaire de leur entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.